.. birdisle-py documentation master file, created by
   sphinx-quickstart on Sun Oct 21 18:02:58 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to birdisle-py's documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   user
   Reference <modules>
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
